"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var Errors = /** @class */ (function () {
    /**
     * Create a new Errors instance.
     */
    function Errors() {
        this.errors = {};
    }
    /**
     * Determine if an errors exists for the given field.
     */
    Errors.prototype.has = function (field, strict) {
        if (strict === void 0) { strict = true; }
        if (strict) {
            return typeof this.errors[field] !== 'undefined';
        }
        return Object.keys(this.errors).some(function (key) { return !!key.match(field); });
    };
    /**
     * Determine if we have any errors.
     */
    Errors.prototype.any = function () {
        return Object.keys(this.errors).length > 0;
    };
    /**
     * Retrieve the error message for a field.
     */
    Errors.prototype.get = function (field) {
        return this.has(field) ? this.errors[field][0] : null;
    };
    /**
     * Retrieve all error messages.
     */
    Errors.prototype.getAll = function () {
        var _this = this;
        return this.any() ? Object.keys(this.errors).map(function (field) { return _this.get(field); }) : [];
    };
    /**
     * Record the new errors.
     */
    Errors.prototype.record = function (errors) {
        this.errors = __assign({}, errors);
    };
    /**
     * Clear one or all error fields.
     */
    Errors.prototype.clear = function (field) {
        var _this = this;
        if (field === void 0) { field = null; }
        if (field) {
            Object.keys(this.errors).forEach(function (key) {
                if (key.match(field)) {
                    delete _this.errors[key];
                }
            });
            return;
        }
        this.errors = {};
    };
    return Errors;
}());
exports.default = Errors;
//# sourceMappingURL=Errors.js.map