import { AxiosError, AxiosRequestConfig, AxiosResponse } from 'axios';
export interface ErrorCallback {
    errorCode: number | number[];
    callback: {
        (error: AxiosError): void;
    };
}
export interface SuccessCallback {
    (response: AxiosResponse): void;
}
export interface RequestConfig {
    autoRequestCsrfCookie?: boolean;
    csrfCookieUrl?: string;
    errorCallbacks?: ErrorCallback[];
    successCallbacks?: SuccessCallback[];
    headers?: {
        [key: string]: string;
    };
}
export default class Request {
    private service;
    private readonly config;
    private static instance;
    private static instanceConfig;
    static getInstance(): Request;
    static setConfig(config: RequestConfig): void;
    static setHeader(name: string, value: string): void;
    private constructor();
    getConfig(): RequestConfig;
    get<T = any, R = AxiosResponse<T>>(url: string, config?: AxiosRequestConfig): Promise<R>;
    post<T = any, R = AxiosResponse<T>>(url: string, data?: any, config?: AxiosRequestConfig): Promise<R>;
    patch<T = any, R = AxiosResponse<T>>(url: string, data?: any, config?: AxiosRequestConfig): Promise<R>;
    put<T = any, R = AxiosResponse<T>>(url: string, data?: any, config?: AxiosRequestConfig): Promise<R>;
    delete<T = any, R = AxiosResponse<T>>(url: string, config?: AxiosRequestConfig): Promise<R>;
}
